@@ -6,7 +6,7 @@ import com.unciv.Constants
 import com.unciv.UncivGame
 import com.unciv.logic.multiplayer.FriendList
 import com.unciv.models.UncivSound
-import com.unciv.ui.utils.Fonts
+import com.unciv.ui.components.Fonts
 import java.text.Collator
 import java.time.Duration
 import java.util.*
